DEFAULT_RESPONSE = {"status": "ok"}

TEST_CAPTION_ITEM = {
    "bit_flags": 0,
    "content_type": "comment",
    "created_at": 1494733796,
    "created_at_utc": 1494733796,
    "did_report_as_spam": False,
    "pk": 17856098620165444,
    "status": "Active",
    "text": "Old Harry Rocks, Dorset, UK\n\n#oldharryrocks #dorset #uk #rocks #clouds #water #photoshoot #nature #amazing #beautifulsky #sky #landscape #nice #beautiful #awesome #landscapes #l4l #f4f",
    "type": 1,
    "user": {
        "full_name": "The best earth places",
        "is_private": False,
        "is_verified": False,
        "pk": 182696006,
        "profile_pic_id": "1477989239094674784_182696006",
        "profile_pic_url": "https://scontent-arn2-1.cdninstagram.com/vp/703a0877fc8653d8b1ec17d57cf0aed6/5B2669EF/t51.2885-19/s150x150/17332952_229750480834181_3303899473574363136_a.jpg",
        "username": "best.earth.places",
    },
    "user_id": 182696006,
}

TEST_COMMENT_ITEM = {
    "bit_flags": 0,
    "comment_like_count": 1,
    "content_type": "comment",
    "created_at": 1494751960,
    "created_at_utc": 1494751960,
    "did_report_as_spam": False,
    "has_liked_comment": True,
    "inline_composer_display_condition": "never",
    "pk": 17856583722163490,
    "status": "Active",
    "text": "Wow awesome take!",
    "type": 0,
    "user": {
        "full_name": "Jon",
        "is_private": False,
        "is_verified": False,
        "pk": 4236956175,
        "profile_pic_id": "1699734799357160789_42369123453",
        "profile_pic_url": "https://scontent-arn2-1.cdninstagram.com/vp/cf320d98994fasdasdas5fa53c698996bfa/5B0AD6BE/t51.2885-19/s150x150/26398129_141825939841889_6195199731287719936_n.jpg",
        "username": "test_user_name",
    },
    "user_id": 4236736455,
}

TEST_USER_ITEM = {
    "pk": 1234543212321,
    "username": "test_username",
    "full_name": "Test Username",
    "is_private": False,
    "profile_pic_url": "https://scontent-arn2-1.cdninstagram.com/vp/6f3e8913b4e9c3153bc15669c47c9519/5AE4F003/t51.2885-19/s150x150/21827786_319483561795594_805639369123123123_n.jpg",
    "profile_pic_id": "120334920291626198135_614512764",
    "friendship_status": {
        "following": True,
        "is_private": False,
        "incoming_request": False,
        "outgoing_request": False,
        "is_bestie": False,
    },
    "is_verified": False,
    "has_anonymous_profile_picture": False,
    "follower_count": 470,
    "byline": "470 followers",
    "social_context": "Following",
    "search_social_context": "Following",
    "mutual_followers_count": 0.0,
    "unseen_count": 0,
}

TEST_USERNAME_INFO_ITEM = {
    "aggregate_promote_engagement": False,
    "allowed_commenter_type": "any",
    "auto_expand_chaining": False,
    "besties_count": 0,
    "biography": "TEST",
    "can_be_tagged_as_sponsor": False,
    "can_boost_post": False,
    "can_convert_to_business": True,
    "can_create_sponsor_tags": False,
    "can_follow_hashtag": False,
    "can_see_organic_insights": False,
    "external_url": "",
    "feed_post_reshare_disabled": False,
    "follower_count": 100,
    "following_count": 100,
    "full_name": "Test user",
    "has_anonymous_profile_picture": False,
    "has_chaining": True,
    "has_highlight_reels": False,
    "has_profile_video_feed": False,
    "hd_profile_pic_url_info": {
        "height": 1080,
        "url": "https://scontent-ams3-1.cdninstagram.com/vp/b99141f9080640b7bec84e7a67caf69e/5B27B215/t51.7777-19/17332952_229750480834181_377777777357477136_a.jpg",
        "width": 1080,
    },
    "hd_profile_pic_versions": [
        {
            "height": 320,
            "url": "https://scontent-ams3-1.cdninstagram.com/vp/d8083f7cb9ec5e0c265ed832867ec62f/5B3C2B1F/t51.7777-19/s320x320/17332952_229750487777777_330377473574363136_a.jpg",
            "width": 320,
        },
        {
            "height": 640,
            "url": "https://scontent-ams3-1.cdninstagram.com/vp/12596165258c466f05979c1be6e95b07/5B294470/t51.7777-19/s640x640/17332952_229750487777777_330377473574363136_a.jpg",
            "width": 640,
        },
    ],
    "include_direct_blacklist_status": True,
    "is_business": False,
    "is_needy": False,
    "is_private": False,
    "is_profile_action_needed": False,
    "is_verified": False,
    "is_video_creator": False,
    "media_count": 100,
    "pk": 7777777777,
    "profile_pic_id": "14779892390947777777_18277776",
    "profile_pic_url": "https://scontent-ams3-1.cdninstagram.com/vp/d056984e148d566bbb15f7eaad55304e/5B4DF6EF/t51.7777-19/s150x150/17377752_27777770480834181_3303899473577777736_a.jpg",
    "recently_bestied_by_count": 0,
    "reel_auto_archive": "unset",
    "show_besties_badge": True,
    "show_business_conversion_icon": False,
    "show_conversion_edit_entry": True,
    "show_insights_terms": False,
    "username": "test_user",
    "usertag_review_enabled": False,
    "usertags_count": 16,
}

TEST_SEARCH_USERNAME_ITEM = {
    "biography": "Some biography",
    "external_url": "",
    "follower_count": 100,
    "following_count": 100,
    "full_name": "Awesome Test User",
    "has_anonymous_profile_picture": False,
    "has_chaining": False,
    "hd_profile_pic_url_info": {
        "height": 440,
        "url": "https://scontent-ams3-1.cdninstagram.com/vp/0049430734318b5063c4cb2cee26862d/5B399C46/t51.2485-29/28435967_574234472958498_24213573932476253432_n.jpg",
        "width": 440,
    },
    "hd_profile_pic_versions": [
        {
            "height": 320,
            "url": "https://scontent-ams3-1.cdninstagram.com/vp/9a869a4fffb0f65b4d850cae433ab00c/5B3B894C/t55.25585-19/s320x320/28435967_574234472958498_24213573958234234236_n.jpg",
            "width": 320,
        }
    ],
    "is_business": False,
    "is_favorite": False,
    "is_private": False,
    "is_verified": False,
    "media_count": 100,
    "pk": 777777777,
    "profile_pic_id": "1727616424669463993_721567777777",
    "profile_pic_url": "https://scontent-ams3-1.cdninstagram.com/vp/86a59b5dadc88e6b6a723b73a6ba25a7/5B271FBC/t51.7777-19/s150x150/28435967_574234472958498_24213577777777777_n.jpg",
    "reel_auto_archive": "unset",
    "username": "awesome.test.user",
    "usertags_count": 0,
}

TEST_PHOTO_ITEM = {
    "taken_at": 1281669687,
    "pk": 1234,
    "id": "1234_19",
    "device_timestamp": 1281669538,
    "media_type": 1,
    "code": "TS",
    "client_cache_key": "MTIzNA==.2",
    "filter_type": 0,
    "image_versions2": {
        "candidates": [
            {
                "width": 612,
                "height": 612,
                "url": "https://scontent-amt2-1.cdninstagram.com/vp/9ef94dbfea2b8cdb2ba5c9b45f1945fd/5AEFE328/t51.2885-15/e15/11137637_1567371843535625_96536034_n.jpg?ig_cache_key=MTIzNA%3D%3D.2",
            },
            {
                "width": 240,
                "height": 240,
                "url": "https://scontent-amt2-1.cdninstagram.com/vp/3f4554f2e45bf356951b2a437ab7d5b1/5ADE3631/t51.2885-15/s240x240/e15/11137637_1567371843535625_96536034_n.jpg?ig_cache_key=MTIzNA%3D%3D.2",
            },
        ]
    },
    "original_width": 612,
    "original_height": 612,
    "lat": 37.3988349713,
    "lng": -122.027721405,
    "user": {
        "pk": 19,
        "username": "chris",
        "full_name": "Chris Messina",
        "is_private": False,
        "profile_pic_url": "https://scontent-amt2-1.cdninstagram.com/t51.2885-19/s150x150/23824744_1036957976446940_7940760494346862592_n.jpg",
        "profile_pic_id": "1654528278723030076_19",
        "friendship_status": {
            "following": False,
            "outgoing_request": False,
            "is_bestie": False,
        },
        "is_verified": False,
        "has_anonymous_profile_picture": False,
        "is_unpublished": False,
        "is_favorite": False,
    },
    "caption": None,
    "caption_is_edited": False,
    "like_count": 260,
    "has_liked": False,
    "top_likers": [],
    "comment_likes_enabled": True,
    "comment_threading_enabled": False,
    "has_more_comments": True,
    "max_num_visible_preview_comments": 2,
    "preview_comments": [],
    "comment_count": 18,
    "photo_of_you": False,
    "can_viewer_save": True,
    "organic_tracking_token": "eyJ2ZXJzaW9uIjo1LCJwYXlsb2FkIjp7ImlzX2FuYWx5dGljc190cmFja2VkIjp0cnVlLCJ1dWlkIjoiYmVkOTQ3ODIzODlkNDE2Nzg2ZTExNDc5ZmExMTkyYTIxMjM0Iiwic2VydmVyX3Rva2VuIjoiMTUxNjIyMTI0MzYxMXwxMjM0fDE4MjY5NjAwNnw5NGQzMjMyMmUxYzgxM2U3MWJmYTZjYzkzZjgxMTgyYzZmMzFmMGUyZTA2ODFjZjI1YzA4YzBiZDFkMWQ3M2U5In0sInNpZ25hdHVyZSI6IiJ9",
}

TEST_TIMELINE_PHOTO_ITEM = {
    "media_or_ad": {
        "taken_at": 1281669687,
        "pk": 1234,
        "id": "1234_19",
        "device_timestamp": 1281669538,
        "media_type": 1,
        "code": "TS",
        "client_cache_key": "MTIzNA==.2",
        "filter_type": 0,
        "image_versions2": {
            "candidates": [
                {
                    "width": 612,
                    "height": 612,
                    "url": "https://scontent-amt2-1.cdninstagram.com/vp/9ef94dbfea2b8cdb2ba5c9b45f1945fd/5AEFE328/t51.2885-15/e15/11137637_1567371843535625_96536034_n.jpg?ig_cache_key=MTIzNA%3D%3D.2",
                },
                {
                    "width": 240,
                    "height": 240,
                    "url": "https://scontent-amt2-1.cdninstagram.com/vp/3f4554f2e45bf356951b2a437ab7d5b1/5ADE3631/t51.2885-15/s240x240/e15/11137637_1567371843535625_96536034_n.jpg?ig_cache_key=MTIzNA%3D%3D.2",
                },
            ]
        },
        "original_width": 612,
        "original_height": 612,
        "lat": 37.3988349713,
        "lng": -122.027721405,
        "user": {
            "pk": 19,
            "username": "chris",
            "full_name": "Chris Messina",
            "is_private": False,
            "profile_pic_url": "https://scontent-amt2-1.cdninstagram.com/t51.2885-19/s150x150/23824744_1036957976446940_7940760494346862592_n.jpg",
            "profile_pic_id": "1654528278723030076_19",
            "friendship_status": {
                "following": False,
                "outgoing_request": False,
                "is_bestie": False,
            },
            "is_verified": False,
            "has_anonymous_profile_picture": False,
            "is_unpublished": False,
            "is_favorite": False,
        },
        "caption": None,
        "caption_is_edited": False,
        "like_count": 260,
        "has_liked": False,
        "top_likers": [],
        "comment_likes_enabled": True,
        "comment_threading_enabled": False,
        "has_more_comments": True,
        "max_num_visible_preview_comments": 2,
        "preview_comments": [],
        "comment_count": 18,
        "photo_of_you": False,
        "can_viewer_save": True,
        "organic_tracking_token": "eyJ2ZXJzaW9uIjo1LCJwYXlsb2FkIjp7ImlzX2FuYWx5dGljc190cmFja2VkIjp0cnVlLCJ1dWlkIjoiYmVkOTQ3ODIzODlkNDE2Nzg2ZTExNDc5ZmExMTkyYTIxMjM0Iiwic2VydmVyX3Rva2VuIjoiMTUxNjIyMTI0MzYxMXwxMjM0fDE4MjY5NjAwNnw5NGQzMjMyMmUxYzgxM2U3MWJmYTZjYzkzZjgxMTgyYzZmMzFmMGUyZTA2ODFjZjI1YzA4YzBiZDFkMWQ3M2U5In0sInNpZ25hdHVyZSI6IiJ9",
    }
}

TEST_USER_TAG_ITEM = {
    u"code": u"BRv8jaDFbsJ",
    u"can_viewer_save": True,
    u"usertags": {
        u"in": [
            {
                u"position": [0.8449074, 0.106481485],
                u"start_time_in_video_in_sec": None,
                u"user": {
                    u"username": u"iceprincezamani",
                    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/af79705613258faaa711b019f7ba7ac4/5CCEBDB3/t51.2885-19/s150x150/41606837_461088254381942_1625040398730657792_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
                    u"profile_pic_id": u"1869904537540938101_184565065",
                    u"full_name": u"Panshak Zamani :-)",
                    u"pk": 184565065,
                    u"is_verified": True,
                    u"is_private": False,
                },
                u"duration_in_video_in_sec": None,
            },
            {
                u"position": [0.6053240999999999, 0.9638888999999999],
                u"start_time_in_video_in_sec": None,
                u"user": {
                    u"username": u"xsproject",
                    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/ce16e991b80484564d2e9b8d6af70094/5CD13391/t51.2885-19/10570253_285800514958746_1157588212_a.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
                    u"full_name": u"XS PROJECT",
                    u"pk": 254488727,
                    u"is_verified": False,
                    u"is_private": False,
                },
                u"duration_in_video_in_sec": None,
            },
            {
                u"position": [0.23263889999999998, 0.7046296],
                u"start_time_in_video_in_sec": None,
                u"user": {
                    u"username": u"maxdevblock",
                    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/ff25ff3b684dea00e1918081c93c20e2/5CBA9941/t51.2885-19/s150x150/15876423_379687975701910_4035551486069964800_a.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
                    u"profile_pic_id": u"1419754651084223374_3998456661",
                    u"full_name": u"\U0001f13c\U0001f130\U0001f147\U0001f173\U0001f174\U0001f185\U0001f131\U0001f13b\U0001f13e\U0001f132\U0001f13a",
                    u"pk": 3998456661,
                    u"is_verified": False,
                    u"is_private": False,
                },
                u"duration_in_video_in_sec": None,
            },
        ]
    },
    u"next_max_id": 17853655591136137,
    u"comment_likes_enabled": True,
    u"max_num_visible_preview_comments": 2,
    u"like_count": 52,
    u"image_versions2": {
        u"candidates": [
            {
                u"url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/aa092049c99e3ad1b6a4c862e347c261/5CD1FFFF/t51.2885-15/e35/17266207_160518517800958_3004377164544999424_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net&se=7&ig_cache_key=MTQ3MjY2MTkxOTExNDgzNjc0NQ%3D%3D.2",
                u"width": 1080,
                u"height": 1350,
            },
            {
                u"url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/9ba27b08ab8a035f0151d6b9a4e2f87e/5CCD7CE4/t51.2885-15/e35/p240x240/17266207_160518517800958_3004377164544999424_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net&ig_cache_key=MTQ3MjY2MTkxOTExNDgzNjc0NQ%3D%3D.2",
                u"width": 240,
                u"height": 300,
            },
        ]
    },
    u"comment_threading_enabled": True,
    u"id": u"1472661919114836745_2308259673",
    u"preview_comments": [
        {
            u"status": u"Active",
            u"user_id": 4556478952,
            u"created_at_utc": 1489818661,
            u"created_at": 1489818661,
            u"bit_flags": 0,
            u"share_enabled": False,
            u"did_report_as_spam": False,
            u"user": {
                u"username": u"webdeveloper_world",
                u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/54a66674c1f1d5cd56b56c75e3d6ec1e/5CCA7BE8/t51.2885-19/s150x150/32233103_638476819831993_8407495672734941184_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
                u"profile_pic_id": u"1442122589220544777_4556478952",
                u"full_name": u"Webdeveloper World",
                u"pk": 4556478952,
                u"is_verified": False,
                u"is_private": False,
            },
            u"content_type": u"comment",
            u"text": u"Brilliant! Best one so far!",
            u"media_id": 1472661919114836745,
            u"pk": 17862027220087150,
            u"type": 0,
        }
    ],
    u"client_cache_key": u"MTQ3MjY2MTkxOTExNDgzNjc0NQ==.2",
    u"device_timestamp": 1489774722152,
    u"comment_count": 3,
    u"media_type": 1,
    u"organic_tracking_token": u"eyJ2ZXJzaW9uIjo1LCJwYXlsb2FkIjp7ImlzX2FuYWx5dGljc190cmFja2VkIjp0cnVlLCJ1dWlkIjoiZjBiNjg4NGY1Zjg4NDk3ZDlkYmUwZDE2OWJhNmFlZGUxNDcyNjYxOTE5MTE0ODM2NzQ1Iiwic2VydmVyX3Rva2VuIjoiMTU0NzYzMDUzNjc1N3wxNDcyNjYxOTE5MTE0ODM2NzQ1fDM5OTg0NTY2NjF8YjY0YzFmNjRmZjM2NjJhMWY0NjgzZWFiY2ZmNzUwN2U4ZDM1OGU3ZDRmOWUyODBkNTljNWYwZjdlNDZiZGFkMyJ9LCJzaWduYXR1cmUiOiIifQ==",
    u"caption_is_edited": False,
    u"inline_composer_display_condition": u"impression_trigger",
    u"original_height": 1350,
    u"filter_type": 112,
    u"user": {
        u"username": u"monsieurwinner",
        u"reel_auto_archive": u"unset",
        u"has_anonymous_profile_picture": False,
        u"is_unpublished": False,
        u"is_favorite": False,
        u"friendship_status": {
            u"following": False,
            u"outgoing_request": False,
            u"is_bestie": False,
        },
        u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/9f47c96e348c6eaaea7cf643ee626008/5CBCD374/t51.2885-19/s150x150/46915113_2288103657891057_3713770861216399360_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
        u"profile_pic_id": u"1942331692376923386_2308259673",
        u"full_name": u"MrWinner CEO Musiklibrary.com",
        u"pk": 2308259673,
        u"is_verified": False,
        u"is_private": False,
    },
    u"pk": 1472661919114836745,
    u"has_liked": True,
    u"has_more_comments": True,
    u"can_view_more_preview_comments": True,
    u"photo_of_you": True,
    u"caption": {
        u"status": u"Active",
        u"user_id": 2308259673,
        u"created_at_utc": 1489775003,
        u"created_at": 1489775003,
        u"bit_flags": 0,
        u"share_enabled": False,
        u"did_report_as_spam": False,
        u"user": {
            u"username": u"monsieurwinner",
            u"reel_auto_archive": u"unset",
            u"has_anonymous_profile_picture": False,
            u"is_unpublished": False,
            u"is_favorite": False,
            u"friendship_status": {
                u"following": False,
                u"outgoing_request": False,
                u"is_bestie": False,
            },
            u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/9f47c96e348c6eaaea7cf643ee626008/5CBCD374/t51.2885-19/s150x150/46915113_2288103657891057_3713770861216399360_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
            u"profile_pic_id": u"1942331692376923386_2308259673",
            u"full_name": u"MrWinner CEO Musiklibrary.com",
            u"pk": 2308259673,
            u"is_verified": False,
            u"is_private": False,
        },
        u"content_type": u"comment",
        u"text": u"#Classicman Programmers are not always busy to the point that, they don't care for themselves. Programmers are #cute #handsome #smart #classicman. We love #program, #code #think #build #test #debugg #run.\n#developer #winner #php #java #webdeveloper #webdesigner #femalecoder #femaleprogrammer #blackAndSmart #blackandclean",
        u"media_id": 1472661919114836745,
        u"pk": 17874973114042066,
        u"type": 1,
    },
    u"taken_at": 1489775002,
    u"original_width": 1080,
    u"can_viewer_reshare": True,
}

TEST_MEDIA_LIKER = {
    u"full_name": u"Instagrambot Instabot",
    u"is_private": False,
    u"is_verified": False,
    u"pk": 9876543210,
    u"profile_pic_id": u"1234567890123456789_123456789",
    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/1234567890abcdef1234567890abcdef/ABCDEF12/t00.0000-00/s150x150/12345678_1234567890123456_1234567890123456789_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
    u"username": u"instabot",
}

TEST_FOLLOWER_ITEM = {
    u"full_name": u"Follower Username",
    u"has_anonymous_profile_picture": False,
    u"is_private": False,
    u"is_verified": False,
    u"pk": 1234567890,
    u"profile_pic_id": u"1234567890123456789_1234567890",
    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/1234567890abcdef1234567890abcdef/ABCDEF12/t00.0000-00/s150x150/12345678_1234567890123456_1234567890123456789_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
    u"reel_auto_archive": u"on",
    u"username": u"follower.username.",
}

TEST_FOLLOWING_ITEM = {
    u"full_name": u"Following Username",
    u"has_anonymous_profile_picture": False,
    u"is_favorite": False,
    u"is_private": False,
    u"is_verified": False,
    u"pk": 1234567890,
    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/1234567890abcdef1234567890abcdef/ABCDEF12/t00.0000-00/s150x150/12345678_1234567890123456_1234567890123456789_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
    u"reel_auto_archive": u"unset",
    u"username": u"following.username",
}

TEST_COMMENT_LIKER_ITEM = {
    u"full_name": u"Instagrambot Instabot",
    u"is_private": False,
    u"is_verified": False,
    u"pk": 9876543210,
    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/1234567890abcdef1234567890abcdef/ABCDEF12/t00.0000-00/s150x150/12345678_1234567890123456_1234567890123456789_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
    u"username": u"instabot",
}

TEST_LOCATION_ITEM = {
    u"header_media": {},
    u"location": {
        u"address": u"",
        u"city": u"Location City Name",
        u"external_source": u"facebook_places",
        u"facebook_places_id": 123456789012345,
        u"lat": 1.2345,
        u"lng": 9.8765,
        u"name": u"City, State",
        u"pk": 123456789,
        u"short_name": u"City",
    },
    u"media_bundles": [],
    u"subtitle": u"",
    u"title": u"City, State",
}

TEST_MOST_RECENT_INVITER_ITEM = {
    u"full_name": u"Inbox User 1",
    u"has_anonymous_profile_picture": False,
    u"is_private": False,
    u"is_verified": False,
    u"pk": 12345678901,
    u"profile_pic_id": u"1952395551539983563_12345678901",
    u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/415ce786f601f6950cedaf19570ee0fd/5CC331E4/t51.2885-19/s150x150/49682915_326457101297245_1431392662795059200_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
    u"reel_auto_archive": u"on",
    u"username": u"inbox_user_1",
}

TEST_INBOX_THREAD_ITEM = {
    u"canonical": True,
    u"has_newer": False,
    u"has_older": True,
    u"inviter": {
        u"full_name": u"Inbox User 2",
        u"has_anonymous_profile_picture": False,
        u"is_private": False,
        u"is_verified": False,
        u"pk": 1234567890,
        u"profile_pic_id": u"1234567890123456789_1234567890",
        u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/e9c32c0f4591557f6beec9cb199a44b4/5CD22060/t51.2885-19/s150x150/12345678_293082444858234_5330756439625433088_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
        u"reel_auto_archive": u"on",
        u"username": u"inbox.user.2",
    },
    u"is_group": False,
    u"is_pin": False,
    u"is_spam": False,
    u"items": [
        {
            u"client_context": u"74a0440f-c5d1-441c-af16-d0e109fc6a3c",
            u"item_id": u"28544793378841687329460340129792000",
            u"item_type": u"text",
            u"text": u"AhHHHH cool",
            u"timestamp": 1547416349724500,
            u"user_id": 1098765432,
        }
    ],
    u"last_activity_at": 1547416349724500,
    u"last_permanent_item": {
        u"client_context": u"74a0440f-c5d1-441c-af16-d0e109fc6a3c",
        u"item_id": u"28544793378841687329460340129792000",
        u"item_type": u"text",
        u"text": u"AhHHHH cool",
        u"timestamp": 1547416349724500,
        u"user_id": 1098765432,
    },
    u"last_seen_at": {
        u"1098765432": {
            u"item_id": u"28544793378841687329460340129792000",
            u"timestamp": u"1547416349724500",
        }
    },
    u"left_users": [],
    u"mentions_muted": False,
    u"muted": False,
    u"named": False,
    u"newest_cursor": u"28544793378841687329460340129792000",
    u"oldest_cursor": u"28544793378841687329460340129792000",
    u"pending": False,
    u"pending_score": 1547416349724500,
    u"thread_id": u"340282366841710300949128210682725503544",
    u"thread_title": u"inbox.user.2",
    u"thread_type": u"private",
    u"thread_v2_id": u"17940844501242424",
    u"users": [
        {
            u"friendship_status": {
                u"blocking": False,
                u"following": True,
                u"incoming_request": False,
                u"is_bestie": False,
                u"is_private": False,
                u"outgoing_request": False,
            },
            u"full_name": u"Inbox User 2",
            u"has_anonymous_profile_picture": False,
            u"is_directapp_installed": False,
            u"is_private": False,
            u"is_verified": False,
            u"pk": 1234567890,
            u"profile_pic_id": u"1234567890123456789_1234567890",
            u"profile_pic_url": u"https://instagram.fmxp5-1.fna.fbcdn.net/vp/e9c32c0f4591557f6beec9cb199a44b4/5CD22060/t51.2885-19/s150x150/12345678_293082444858234_5330756439625433088_n.jpg?_nc_ht=instagram.fmxp5-1.fna.fbcdn.net",
            u"reel_auto_archive": u"on",
            u"username": u"inbox.user.2",
        }
    ],
    u"valued_request": False,
    u"vc_muted": False,
    u"viewer_id": 1098765432,
}
